NAME = "blue_sandbox"

ICON = "🌀"

DESCRIPTION = f"{ICON} A sandbox for ideas and experiments."

VERSION = "5.148.1"

REPO_NAME = "blue-sandbox"

MARQUEE = (
    "https://github.com/kamangir/assets/raw/main/blue-sandbox/marquee.png?raw=true"
)

ALIAS = "@sandbox"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
