list_of_experiments = {
    "palisades": {
        "ICON": "🧑🏽‍🚒",
        "title": "Post-disaster Land Cover Classification.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/palisades/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-geo/Maxar-Open-Datacube.png?raw=true",
        "status": "🔥",
    },
    "sagesemseg": {
        "ICON": "🌀",
        "title": "A SemSeg (Semantic Segmenter) trained and deployed on AWS Sagemaker.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/sagesemseg/README.md",
        "marquee": "https://github.com/kamangir/assets/blob/main/blue-sandbox/sagesemseg-predict.png?raw=true",
        "status": "⏸️",
    },
    "`@damages`": {
        "ICON": "🌐",
        "title": "Satellite imagery damage assessment workflow",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/microsoft_building_damage_assessment/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-sandbox/Maui-Hawaii-fires-Aug-23-ingest-2025-01-10-qqJqhm.png?raw=true",
        "status": "⏸️",
    },
    "cemetery": {
        "ICON": "🪦",
        "title": "An AI cemetery.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/cemetery/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        "status": "🪦",
    },
    "template": {
        "ICON": "",
        "title": "",
        "url": "",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        "status": "🎰",
    },
}
